Getting support for Weblate
===========================

Weblate is a copylefted libre software with community support. Subscribers
receive priority support at no extra charge. Prepaid help packages are
available for everyone. You can find more information about current support
offerings at <https://weblate.org/support/>.

.. _activate-support:

Activating support
------------------

Since Weblate 3.8 the purchased support packages can be activated in a Weblate
management interface. The activation will enable peridic registration on
Weblate servers. This allows you to directly navigate to your Weblate
installation from subscription management and sends basic telemetry to Weblate
servers.

.. image:: /images/support.png

Data submitted to the server
----------------------------

The submitted data include:

* URL where Weblate is configured
* Site title
* Weblate version
* Counts of some objects in Weblate database (projects, components, languages, source strings and users)
* Public SSH key

No other data is submitted.

.. hint::

   The activation is fully optional, you can still use support services without it.
